Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package +k8s:defaulter-gen=TypeMeta +groupName=packaging.carvel.dev
Index ¶
- Variables
- func Resource(resource string) schema.GroupResource
- type PackageInstall
- type PackageInstallList
- type PackageInstallSpec
- type PackageInstallStatus
- type PackageInstallValues
- type PackageInstallValuesSecretRef
- type PackageRef
- type PackageRepository
- type PackageRepositoryFetch
- type PackageRepositoryList
- type PackageRepositorySpec
- type PackageRepositoryStatus
Constants ¶
This section is empty.
Variables ¶
var ( SchemeBuilder runtime.SchemeBuilder AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: "packaging.carvel.dev", Version: "v1alpha1"}
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Types ¶
type PackageInstall ¶
type PackageInstall struct {
metav1.TypeMeta `json:",inline"`
// Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata.
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PackageInstallSpec `json:"spec"`
// +optional
Status PackageInstallStatus `json:"status,omitempty"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object +kubebuilder:subresource:status +kubebuilder:resource:shortName=pkgi,categories={carvel} +kubebuilder:printcolumn:name=Package name,JSONPath=.spec.packageRef.refName,description=PackageMetadata name,type=string +kubebuilder:printcolumn:name=Package version,JSONPath=.status.version,description=PackageMetadata version,type=string +kubebuilder:printcolumn:name=Description,JSONPath=.status.friendlyDescription,description=Friendly description,type=string +kubebuilder:printcolumn:name=Age,JSONPath=.metadata.creationTimestamp,description=Time since creation,type=date +kubebuilder:printcolumn:name=Paused,JSONPath=.spec.paused,description=Paused,type=boolean A Package Install is an actual installation of a package and its underlying resources on a Kubernetes cluster. It is represented in kapp-controller by a PackageInstall CR. A PackageInstall CR must reference a Package CR.
func (*PackageInstall) DeepCopy ¶
func (in *PackageInstall) DeepCopy() *PackageInstall
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstall.
func (*PackageInstall) DeepCopyInto ¶
func (in *PackageInstall) DeepCopyInto(out *PackageInstall)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageInstall) DeepCopyObject ¶
func (in *PackageInstall) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageInstallList ¶
type PackageInstallList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []PackageInstall `json:"items"`
}
+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PackageInstallList) DeepCopy ¶
func (in *PackageInstallList) DeepCopy() *PackageInstallList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstallList.
func (*PackageInstallList) DeepCopyInto ¶
func (in *PackageInstallList) DeepCopyInto(out *PackageInstallList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageInstallList) DeepCopyObject ¶
func (in *PackageInstallList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageInstallSpec ¶
type PackageInstallSpec struct {
// Specifies service account that will be used to install underlying package contents
// +optional
ServiceAccountName string `json:"serviceAccountName,omitempty"`
// Specifies that Package should be deployed to destination cluster;
// by default, cluster is same as where this resource resides (optional)
// +optional
Cluster *v1alpha1.AppCluster `json:"cluster,omitempty"`
// Specifies the name of the package to install (required)
// +optional
PackageRef *PackageRef `json:"packageRef,omitempty"`
// Values to be included in package's templating step
// (currently only included in the first templating step) (optional)
// +optional
Values []PackageInstallValues `json:"values,omitempty"`
// Paused when set to true will ignore all pending changes,
// once it set back to false, pending changes will be applied
// +optional
Paused bool `json:"paused,omitempty"`
// Canceled when set to true will stop all active changes
// +optional
Canceled bool `json:"canceled,omitempty"`
// Controls frequency of App reconciliation in time + unit
// format. Always >= 30s. If value below 30s is specified,
// 30s will be used.
// +optional
SyncPeriod *metav1.Duration `json:"syncPeriod,omitempty"`
// When NoopDelete set to true, PackageInstall deletion
// should delete PackageInstall/App CR but preserve App's
// associated resources.
// +optional
NoopDelete bool `json:"noopDelete,omitempty"`
// Specifies the default namespace to install the Package resources, by default this is
// same as the PackageInstall namespace (optional; v0.48.0+)
// +optional
DefaultNamespace string `json:"defaultNamespace,omitempty"`
}
func (*PackageInstallSpec) DeepCopy ¶
func (in *PackageInstallSpec) DeepCopy() *PackageInstallSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstallSpec.
func (*PackageInstallSpec) DeepCopyInto ¶
func (in *PackageInstallSpec) DeepCopyInto(out *PackageInstallSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageInstallStatus ¶
type PackageInstallStatus struct {
// +optional
v1alpha1.GenericStatus `json:",inline"`
// TODO this is desired resolved version (not actually deployed)
// +optional
Version string `json:"version,omitempty"`
// LastAttemptedVersion specifies what version was last attempted to be installed.
// It does _not_ indicate it was successfully installed.
// +optional
LastAttemptedVersion string `json:"lastAttemptedVersion,omitempty"`
}
func (*PackageInstallStatus) DeepCopy ¶
func (in *PackageInstallStatus) DeepCopy() *PackageInstallStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstallStatus.
func (*PackageInstallStatus) DeepCopyInto ¶
func (in *PackageInstallStatus) DeepCopyInto(out *PackageInstallStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageInstallValues ¶
type PackageInstallValues struct {
// +optional
SecretRef *PackageInstallValuesSecretRef `json:"secretRef,omitempty"`
}
func (*PackageInstallValues) DeepCopy ¶
func (in *PackageInstallValues) DeepCopy() *PackageInstallValues
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstallValues.
func (*PackageInstallValues) DeepCopyInto ¶
func (in *PackageInstallValues) DeepCopyInto(out *PackageInstallValues)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageInstallValuesSecretRef ¶
type PackageInstallValuesSecretRef struct {
// +optional
Name string `json:"name,omitempty"`
// +optional
Key string `json:"key,omitempty"`
}
func (*PackageInstallValuesSecretRef) DeepCopy ¶
func (in *PackageInstallValuesSecretRef) DeepCopy() *PackageInstallValuesSecretRef
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageInstallValuesSecretRef.
func (*PackageInstallValuesSecretRef) DeepCopyInto ¶
func (in *PackageInstallValuesSecretRef) DeepCopyInto(out *PackageInstallValuesSecretRef)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageRef ¶
type PackageRef struct {
// +optional
RefName string `json:"refName,omitempty"`
// +optional
VersionSelection *versions.VersionSelectionSemver `json:"versionSelection,omitempty"`
}
func (*PackageRef) DeepCopy ¶
func (in *PackageRef) DeepCopy() *PackageRef
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRef.
func (*PackageRef) DeepCopyInto ¶
func (in *PackageRef) DeepCopyInto(out *PackageRef)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageRepository ¶
type PackageRepository struct {
metav1.TypeMeta `json:",inline"`
// Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata.
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PackageRepositorySpec `json:"spec"`
// +optional
Status PackageRepositoryStatus `json:"status,omitempty"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object +kubebuilder:subresource:status +kubebuilder:resource:shortName=pkgr,categories={carvel} +kubebuilder:printcolumn:name=Age,JSONPath=.metadata.creationTimestamp,description=Time since creation,type=date +kubebuilder:printcolumn:name=Description,JSONPath=.status.friendlyDescription,description=Friendly description,type=string +kubebuilder:printcolumn:name=Paused,JSONPath=.spec.paused,description=Paused,type=boolean A package repository is a collection of packages and their metadata. Similar to a maven repository or a rpm repository, adding a package repository to a cluster gives users of that cluster the ability to install any of the packages from that repository.
func (*PackageRepository) DeepCopy ¶
func (in *PackageRepository) DeepCopy() *PackageRepository
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRepository.
func (*PackageRepository) DeepCopyInto ¶
func (in *PackageRepository) DeepCopyInto(out *PackageRepository)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageRepository) DeepCopyObject ¶
func (in *PackageRepository) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageRepositoryFetch ¶
type PackageRepositoryFetch struct {
// Image url; unqualified, tagged, or
// digest references supported (required)
// +optional
Image *v1alpha1.AppFetchImage `json:"image,omitempty"`
// Uses http library to fetch file containing packages
// +optional
HTTP *v1alpha1.AppFetchHTTP `json:"http,omitempty"`
// Uses git to clone repository containing package list
// +optional
Git *v1alpha1.AppFetchGit `json:"git,omitempty"`
// Pulls imgpkg bundle from Docker/OCI registry
// +optional
ImgpkgBundle *v1alpha1.AppFetchImgpkgBundle `json:"imgpkgBundle,omitempty"`
// Pull content from within this resource; or other resources in the cluster
// +optional
Inline *v1alpha1.AppFetchInline `json:"inline,omitempty"`
}
func (*PackageRepositoryFetch) DeepCopy ¶
func (in *PackageRepositoryFetch) DeepCopy() *PackageRepositoryFetch
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRepositoryFetch.
func (*PackageRepositoryFetch) DeepCopyInto ¶
func (in *PackageRepositoryFetch) DeepCopyInto(out *PackageRepositoryFetch)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageRepositoryList ¶
type PackageRepositoryList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []PackageRepository `json:"items"`
}
+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PackageRepositoryList) DeepCopy ¶
func (in *PackageRepositoryList) DeepCopy() *PackageRepositoryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRepositoryList.
func (*PackageRepositoryList) DeepCopyInto ¶
func (in *PackageRepositoryList) DeepCopyInto(out *PackageRepositoryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageRepositoryList) DeepCopyObject ¶
func (in *PackageRepositoryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageRepositorySpec ¶
type PackageRepositorySpec struct {
// Paused when set to true will ignore all pending changes,
// once it set back to false, pending changes will be applied
// +optional
Paused bool `json:"paused,omitempty"`
// Controls frequency of PackageRepository reconciliation
// +optional
SyncPeriod *metav1.Duration `json:"syncPeriod,omitempty"`
Fetch *PackageRepositoryFetch `json:"fetch"`
}
func (*PackageRepositorySpec) DeepCopy ¶
func (in *PackageRepositorySpec) DeepCopy() *PackageRepositorySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRepositorySpec.
func (*PackageRepositorySpec) DeepCopyInto ¶
func (in *PackageRepositorySpec) DeepCopyInto(out *PackageRepositorySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageRepositoryStatus ¶
type PackageRepositoryStatus struct {
// +optional
Fetch *v1alpha1.AppStatusFetch `json:"fetch,omitempty"`
// +optional
Template *v1alpha1.AppStatusTemplate `json:"template,omitempty"`
// +optional
Deploy *v1alpha1.AppStatusDeploy `json:"deploy,omitempty"`
// +optional
ConsecutiveReconcileSuccesses int `json:"consecutiveReconcileSuccesses,omitempty"`
// +optional
ConsecutiveReconcileFailures int `json:"consecutiveReconcileFailures,omitempty"`
// +optional
v1alpha1.GenericStatus `json:",inline"`
}
func (*PackageRepositoryStatus) DeepCopy ¶
func (in *PackageRepositoryStatus) DeepCopy() *PackageRepositoryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageRepositoryStatus.
func (*PackageRepositoryStatus) DeepCopyInto ¶
func (in *PackageRepositoryStatus) DeepCopyInto(out *PackageRepositoryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.