Documentation
¶
Overview ¶
The internal version of the package api.
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type AppTemplateSpec
- type IncludedSoftware
- type Maintainer
- type Package
- type PackageList
- type PackageMetadata
- type PackageMetadataList
- type PackageMetadataSpec
- type PackageSpec
- type ValuesSchema
- type VersionSelection
Constants ¶
const GroupName = "data.packaging.carvel.dev"
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns back a Group qualified GroupResource
Types ¶
type AppTemplateSpec ¶
type AppTemplateSpec struct {
Spec *kcv1alpha1.AppSpec `json:"spec"`
}
func (*AppTemplateSpec) DeepCopy ¶
func (in *AppTemplateSpec) DeepCopy() *AppTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AppTemplateSpec.
func (*AppTemplateSpec) DeepCopyInto ¶
func (in *AppTemplateSpec) DeepCopyInto(out *AppTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IncludedSoftware ¶
type IncludedSoftware struct {
DisplayName string `json:"displayName,omitempty" protobuf:"bytes,1,opt,name=displayName"`
Version string `json:"version,omitempty" protobuf:"bytes,2,opt,name=version"`
Description string `json:"description,omitempty" protobuf:"bytes,3,opt,name=description"`
}
IncludedSoftware contains the underlying Software Contents of a Package
func (*IncludedSoftware) DeepCopy ¶
func (in *IncludedSoftware) DeepCopy() *IncludedSoftware
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IncludedSoftware.
func (*IncludedSoftware) DeepCopyInto ¶
func (in *IncludedSoftware) DeepCopyInto(out *IncludedSoftware)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Maintainer ¶
type Maintainer struct {
Name string `json:"name,omitempty"`
}
func (*Maintainer) DeepCopy ¶
func (in *Maintainer) DeepCopy() *Maintainer
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Maintainer.
func (*Maintainer) DeepCopyInto ¶
func (in *Maintainer) DeepCopyInto(out *Maintainer)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Package ¶
type Package struct {
metav1.TypeMeta `json:",inline"`
// Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata.
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PackageSpec `json:"spec"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object A package is a combination of configuration metadata and OCI images that informs the package manager what software it holds and how to install itself onto a Kubernetes cluster. For example, an nginx-ingress package would instruct the package manager where to download the nginx container image, how to configure the associated Deployment, and install it into a cluster.
func (*Package) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Package.
func (*Package) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Package) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageList ¶
type PackageList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []Package `json:"items"`
}
+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PackageList) DeepCopy ¶
func (in *PackageList) DeepCopy() *PackageList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageList.
func (*PackageList) DeepCopyInto ¶
func (in *PackageList) DeepCopyInto(out *PackageList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageList) DeepCopyObject ¶
func (in *PackageList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageMetadata ¶
type PackageMetadata struct {
metav1.TypeMeta `json:",inline"`
// Standard object metadata; More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata.
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PackageMetadataSpec `json:"spec"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object Package Metadata are attributes of a single package that do not change frequently and that are shared across multiple versions of a single package. It contains information similar to a project’s README.md.
func (*PackageMetadata) DeepCopy ¶
func (in *PackageMetadata) DeepCopy() *PackageMetadata
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageMetadata.
func (*PackageMetadata) DeepCopyInto ¶
func (in *PackageMetadata) DeepCopyInto(out *PackageMetadata)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageMetadata) DeepCopyObject ¶
func (in *PackageMetadata) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageMetadataList ¶
type PackageMetadataList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []PackageMetadata `json:"items"`
}
+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*PackageMetadataList) DeepCopy ¶
func (in *PackageMetadataList) DeepCopy() *PackageMetadataList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageMetadataList.
func (*PackageMetadataList) DeepCopyInto ¶
func (in *PackageMetadataList) DeepCopyInto(out *PackageMetadataList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PackageMetadataList) DeepCopyObject ¶
func (in *PackageMetadataList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PackageMetadataSpec ¶
type PackageMetadataSpec struct {
// Human friendly name of the package (optional; string)
DisplayName string `json:"displayName,omitempty"`
// Long description of the package (optional; string)
LongDescription string `json:"longDescription,omitempty"`
// Short desription of the package (optional; string)
ShortDescription string `json:"shortDescription,omitempty"`
// Base64 encoded icon (optional; string)
IconSVGBase64 string `json:"iconSVGBase64,omitempty"`
// Name of the entity distributing the package (optional; string)
ProviderName string `json:"providerName,omitempty"`
// List of maintainer info for the package.
// Currently only supports the name key. (optional; array of maintner info)
Maintainers []Maintainer `json:"maintainers,omitempty"`
// Classifiers of the package (optional; Array of strings)
Categories []string `json:"categories,omitempty"`
// Description of the support available for the package (optional; string)
SupportDescription string `json:"supportDescription,omitempty"`
}
func (*PackageMetadataSpec) DeepCopy ¶
func (in *PackageMetadataSpec) DeepCopy() *PackageMetadataSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageMetadataSpec.
func (*PackageMetadataSpec) DeepCopyInto ¶
func (in *PackageMetadataSpec) DeepCopyInto(out *PackageMetadataSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PackageSpec ¶
type PackageSpec struct {
// The name of the PackageMetadata associated with this version
// Must be a valid PackageMetadata name (see PackageMetadata CR for details)
// Cannot be empty
RefName string `json:"refName,omitempty"`
// Package version; Referenced by PackageInstall;
// Must be valid semver (required)
// Cannot be empty
Version string `json:"version,omitempty"`
// Description of the licenses that apply to the package software
// (optional; Array of strings)
Licenses []string `json:"licenses,omitempty"`
// Timestamp of release (iso8601 formatted string; optional)
// +optional
// +nullable
ReleasedAt metav1.Time `json:"releasedAt,omitempty"`
// System requirements needed to install the package.
// Note: these requirements will not be verified by kapp-controller on
// installation. (optional; string)
CapactiyRequirementsDescription string `json:"capacityRequirementsDescription,omitempty"`
// Version release notes (optional; string)
ReleaseNotes string `json:"releaseNotes,omitempty"`
Template AppTemplateSpec `json:"template,omitempty"`
// valuesSchema can be used to show template values that
// can be configured by users when a Package is installed
// in an OpenAPI schema format.
// +optional
ValuesSchema ValuesSchema `json:"valuesSchema,omitempty"`
// IncludedSoftware can be used to show the software contents of a Package.
// This is especially useful if the underlying versions do not match the Package version
// +optional
IncludedSoftware []IncludedSoftware `json:"includedSoftware,omitempty"`
// KappControllerVersionSelection specifies the versions of kapp-controller which can install this package
// +optional
KappControllerVersionSelection *VersionSelection `json:"kappControllerVersionSelection,omitempty" protobuf:"bytes,10,opt,name=kappControllerVersionSelection"`
// KubernetesVersionSelection specifies the versions of k8s which this package can be installed on
// +optional
KubernetesVersionSelection *VersionSelection `json:"kubernetesVersionSelection,omitempty" protobuf:"bytes,11,opt,name=kubernetesVersionSelection"`
}
func (*PackageSpec) DeepCopy ¶
func (in *PackageSpec) DeepCopy() *PackageSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PackageSpec.
func (*PackageSpec) DeepCopyInto ¶
func (in *PackageSpec) DeepCopyInto(out *PackageSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ValuesSchema ¶
type ValuesSchema struct {
// +optional
// +nullable
// +kubebuilder:pruning:PreserveUnknownFields
OpenAPIv3 runtime.RawExtension `json:"openAPIv3,omitempty"`
}
func (*ValuesSchema) DeepCopy ¶
func (in *ValuesSchema) DeepCopy() *ValuesSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ValuesSchema.
func (*ValuesSchema) DeepCopyInto ¶
func (in *ValuesSchema) DeepCopyInto(out *ValuesSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VersionSelection ¶
type VersionSelection struct {
Constraints string `json:"constraints,omitempty" protobuf:"bytes,1,opt,name=constraints"`
}
VersionSelection provides version range constraints but will always accept prereleases
func (*VersionSelection) DeepCopy ¶
func (in *VersionSelection) DeepCopy() *VersionSelection
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VersionSelection.
func (*VersionSelection) DeepCopyInto ¶
func (in *VersionSelection) DeepCopyInto(out *VersionSelection)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Directories
¶
| Path | Synopsis |
|---|---|
|
PackageMetadata v1alpha1 is the v1alpha1 version of the PackageMetadata API.
|
PackageMetadata v1alpha1 is the v1alpha1 version of the PackageMetadata API. |