Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppLister ¶
type AppLister interface {
// List lists all Apps in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.App, err error)
// Apps returns an object that can list and get Apps.
Apps(namespace string) AppNamespaceLister
AppListerExpansion
}
AppLister helps list Apps. All objects returned here must be treated as read-only.
func NewAppLister ¶
NewAppLister returns a new AppLister.
type AppListerExpansion ¶
type AppListerExpansion interface{}
AppListerExpansion allows custom methods to be added to AppLister.
type AppNamespaceLister ¶
type AppNamespaceLister interface {
// List lists all Apps in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.App, err error)
// Get retrieves the App from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.App, error)
AppNamespaceListerExpansion
}
AppNamespaceLister helps list and get Apps. All objects returned here must be treated as read-only.
type AppNamespaceListerExpansion ¶
type AppNamespaceListerExpansion interface{}
AppNamespaceListerExpansion allows custom methods to be added to AppNamespaceLister.
Click to show internal directories.
Click to hide internal directories.